@@ -16,7 +16,7 @@
 
 package com.google.errorprone;
 
-import com.google.auto.value.AutoValue;
+import com.google.auto.value.AutoBuilder;
 import com.google.common.base.Optional;
 import com.google.common.base.Preconditions;
 import com.google.common.base.Splitter;
@@ -103,31 +103,25 @@ public class ErrorProneOptions {
     ERROR
   }
 
-  @AutoValue
-  abstract static class PatchingOptions {
+  record PatchingOptions(
+      ImmutableSet<String> namedCheckers,
+      boolean inPlace,
+      String baseDirectory,
+      Optional<Supplier<CodeTransformer>> customRefactorer,
+      ImportOrganizer importOrganizer) {
     final boolean doRefactor() {
       return inPlace() || !baseDirectory().isEmpty();
     }
 
-    abstract ImmutableSet<String> namedCheckers();
-
-    abstract boolean inPlace();
-
-    abstract String baseDirectory();
-
-    abstract Optional<Supplier<CodeTransformer>> customRefactorer();
-
-    abstract ImportOrganizer importOrganizer();
-
     static Builder builder() {
-      return new AutoValue_ErrorProneOptions_PatchingOptions.Builder()
+      return new AutoBuilder_ErrorProneOptions_PatchingOptions_Builder()
           .baseDirectory("")
           .inPlace(false)
           .namedCheckers(ImmutableSet.of())
           .importOrganizer(ImportOrganizer.STATIC_FIRST_ORGANIZER);
     }
 
-    @AutoValue.Builder
+    @AutoBuilder
     abstract static class Builder {
 
       abstract Builder namedCheckers(ImmutableSet<String> checkers);
@@ -292,41 +286,41 @@ public class ErrorProneOptions {
       severityMap.put(checkName, severity);
     }
 
-    public void parseFlag(String flag) {
+    void parseFlag(String flag) {
       flagsBuilder.parseFlag(flag);
     }
 
-    public void setIgnoreSuppressionAnnotations(boolean ignoreSuppressionAnnotations) {
+    void setIgnoreSuppressionAnnotations(boolean ignoreSuppressionAnnotations) {
       this.ignoreSuppressionAnnotations = ignoreSuppressionAnnotations;
     }
 
-    public void setIgnoreUnknownChecks(boolean ignoreUnknownChecks) {
+    void setIgnoreUnknownChecks(boolean ignoreUnknownChecks) {
       this.ignoreUnknownChecks = ignoreUnknownChecks;
     }
 
-    public void setDisableWarningsInGeneratedCode(boolean disableWarningsInGeneratedCode) {
+    void setDisableWarningsInGeneratedCode(boolean disableWarningsInGeneratedCode) {
       this.disableWarningsInGeneratedCode = disableWarningsInGeneratedCode;
     }
 
-    public void setDropErrorsToWarnings(boolean dropErrorsToWarnings) {
+    void setDropErrorsToWarnings(boolean dropErrorsToWarnings) {
       severityMap.entrySet().stream()
           .filter(e -> e.getValue() == Severity.ERROR)
           .forEach(e -> e.setValue(Severity.WARN));
       this.dropErrorsToWarnings = dropErrorsToWarnings;
     }
 
-    public void setSuggestionsAsWarnings(boolean suggestionsAsWarnings) {
+    void setSuggestionsAsWarnings(boolean suggestionsAsWarnings) {
       this.suggestionsAsWarnings = suggestionsAsWarnings;
     }
 
-    public void setDisableAllWarnings(boolean disableAllWarnings) {
+    void setDisableAllWarnings(boolean disableAllWarnings) {
       severityMap.entrySet().stream()
           .filter(e -> e.getValue() == Severity.WARN)
           .forEach(e -> e.setValue(Severity.OFF));
       this.disableAllWarnings = disableAllWarnings;
     }
 
-    public void setEnableAllChecksAsWarnings(boolean enableAllChecksAsWarnings) {
+    void setEnableAllChecksAsWarnings(boolean enableAllChecksAsWarnings) {
       // Checks manually disabled before this flag are reset to warning-level
       severityMap.entrySet().stream()
           .filter(e -> e.getValue() == Severity.OFF)
@@ -334,29 +328,29 @@ public class ErrorProneOptions {
       this.enableAllChecksAsWarnings = enableAllChecksAsWarnings;
     }
 
-    public void setIgnoreLargeCodeGenerators(boolean ignoreLargeCodeGenerators) {
+    void setIgnoreLargeCodeGenerators(boolean ignoreLargeCodeGenerators) {
       this.ignoreLargeCodeGenerators = ignoreLargeCodeGenerators;
     }
 
-    public void setDisableAllChecks(boolean disableAllChecks) {
+    void setDisableAllChecks(boolean disableAllChecks) {
       // Discard previously set severities so that the DisableAllChecks flag is position sensitive.
       severityMap.clear();
       this.disableAllChecks = disableAllChecks;
     }
 
-    public void setTestOnlyTarget(boolean isTestOnlyTarget) {
+    void setTestOnlyTarget(boolean isTestOnlyTarget) {
       this.isTestOnlyTarget = isTestOnlyTarget;
     }
 
-    public void setPubliclyVisibleTarget(boolean isPubliclyVisibleTarget) {
+    void setPubliclyVisibleTarget(boolean isPubliclyVisibleTarget) {
       this.isPubliclyVisibleTarget = isPubliclyVisibleTarget;
     }
 
-    public PatchingOptions.Builder patchingOptionsBuilder() {
+    PatchingOptions.Builder patchingOptionsBuilder() {
       return patchingOptionsBuilder;
     }
 
-    public ErrorProneOptions build(ImmutableList<String> remainingArgs) {
+    ErrorProneOptions build(ImmutableList<String> remainingArgs) {
       return new ErrorProneOptions(
           ImmutableMap.copyOf(severityMap),
           remainingArgs,
@@ -376,7 +370,7 @@ public class ErrorProneOptions {
           ignoreLargeCodeGenerators);
     }
 
-    public void setExcludedPattern(Pattern excludedPattern) {
+    void setExcludedPattern(Pattern excludedPattern) {
       this.excludedPattern = excludedPattern;
     }
   }
