@@ -1543,30 +1543,8 @@ public class ASTHelpers {
     if (compound == null) {
       return null;
     }
-    return annotationTargetType(TypeAnnotations.instance(state.context), anno, compound, target);
-  }
-
-  private static AnnotationType annotationTargetType(
-      TypeAnnotations typeAnnotations,
-      AnnotationTree tree,
-      Compound compound,
-      @Nullable Symbol target) {
-    try {
-      try {
-        // the JCTree argument was added in JDK 21
-        return (AnnotationType)
-            TypeAnnotations.class
-                .getMethod("annotationTargetType", JCTree.class, Compound.class, Symbol.class)
-                .invoke(typeAnnotations, tree, compound, target);
-      } catch (NoSuchMethodException e1) {
-        return (AnnotationType)
-            TypeAnnotations.class
-                .getMethod("annotationTargetType", Compound.class, Symbol.class)
-                .invoke(typeAnnotations, compound, target);
-      }
-    } catch (ReflectiveOperationException e) {
-      throw new LinkageError(e.getMessage(), e);
-    }
+    return TypeAnnotations.instance(state.context)
+        .annotationTargetType((JCTree) anno, compound, target);
   }
 
   /**
@@ -1699,9 +1677,10 @@ public class ASTHelpers {
   }
 
   public static boolean isSuper(Tree tree) {
-    return switch (tree.getKind()) {
-      case IDENTIFIER -> ((IdentifierTree) tree).getName().contentEquals("super");
-      case MEMBER_SELECT -> ((MemberSelectTree) tree).getIdentifier().contentEquals("super");
+    return switch (tree) {
+      case IdentifierTree identifierTree -> identifierTree.getName().contentEquals("super");
+      case MemberSelectTree memberSelectTree ->
+          memberSelectTree.getIdentifier().contentEquals("super");
       default -> false;
     };
   }
@@ -2151,7 +2130,9 @@ public class ASTHelpers {
 
   /** Returns whether the given tree has an explicit source code representation. */
   public static boolean hasExplicitSource(Tree tree, VisitorState state) {
-    return getStartPosition(tree) != Position.NOPOS && state.getEndPosition(tree) != Position.NOPOS;
+    int pos = getStartPosition(tree);
+    int endPos = state.getEndPosition(tree);
+    return pos != Position.NOPOS && endPos != Position.NOPOS && pos != endPos;
   }
 
   /** Returns {@code true} if this symbol was declared in Kotlin source. */
