@@ -21,6 +21,7 @@ import static com.google.common.collect.ImmutableList.toImmutableList;
 import static com.google.errorprone.BugPattern.SeverityLevel.WARNING;
 import static com.google.errorprone.matchers.Description.NO_MATCH;
 import static com.google.errorprone.util.ASTHelpers.getStartPosition;
+import static com.google.errorprone.util.ASTHelpers.hasExplicitSource;
 
 import com.google.common.base.Preconditions;
 import com.google.common.base.Strings;
@@ -67,29 +68,44 @@ public class ParameterName extends BugChecker
     implements MethodInvocationTreeMatcher, NewClassTreeMatcher {
 
   private final ImmutableList<String> exemptPackages;
+  private final boolean matchImplicitSource;
 
   @Inject
-  ParameterName(ErrorProneFlags errorProneFlags) {
+  ParameterName(ErrorProneFlags flags) {
     this.exemptPackages =
-        errorProneFlags.getListOrEmpty("ParameterName:exemptPackagePrefixes").stream()
+        flags.getListOrEmpty("ParameterName:exemptPackagePrefixes").stream()
             // add a trailing '.' so that e.g. com.foo matches as a prefix of com.foo.bar, but not
             // com.foobar
             .map(p -> p.endsWith(".") ? p : p + ".")
             .collect(toImmutableList());
+    this.matchImplicitSource = flags.getBoolean("ParameterName:matchImplicitSource").orElse(true);
   }
 
   @Override
   public Description matchMethodInvocation(MethodInvocationTree tree, VisitorState state) {
-    checkArguments(tree, tree.getArguments(), state.getEndPosition(tree.getMethodSelect()), state);
+    checkArguments(
+        tree, tree.getArguments(), argListStartPosition(tree.getMethodSelect(), state), state);
     return NO_MATCH;
   }
 
   @Override
   public Description matchNewClass(NewClassTree tree, VisitorState state) {
-    checkArguments(tree, tree.getArguments(), state.getEndPosition(tree.getIdentifier()), state);
+    checkArguments(
+        tree, tree.getArguments(), argListStartPosition(tree.getIdentifier(), state), state);
     return NO_MATCH;
   }
 
+  int argListStartPosition(Tree tree, VisitorState state) {
+    if (!matchImplicitSource && !hasExplicitSource(tree, state)) {
+      return Position.NOPOS;
+    }
+    int pos = state.getEndPosition(tree);
+    if (pos != Position.NOPOS) {
+      return pos;
+    }
+    return getStartPosition(tree);
+  }
+
   private void checkArguments(
       Tree tree,
       List<? extends ExpressionTree> arguments,
