@@ -40,6 +40,8 @@ import com.google.errorprone.fixes.Replacement;
 import com.google.errorprone.fixes.SuggestedFix;
 import com.google.errorprone.fixes.SuggestedFixes;
 import com.google.errorprone.matchers.Description;
+import com.sun.source.tree.BlockTree;
+import com.sun.source.tree.CompilationUnitTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
 import com.sun.source.tree.MemberSelectTree;
@@ -52,7 +54,6 @@ import com.sun.tools.javac.code.Symbol;
 import com.sun.tools.javac.code.Symbol.MethodSymbol;
 import com.sun.tools.javac.code.Symbol.VarSymbol;
 import com.sun.tools.javac.code.Type;
-import com.sun.tools.javac.tree.JCTree;
 import com.sun.tools.javac.tree.JCTree.JCCompilationUnit;
 import java.util.Objects;
 import java.util.Optional;
@@ -130,14 +131,9 @@ public class UnnecessaryAnonymousClass extends BugChecker implements VariableTre
     fixBuilder.merge(trimToMethodDef(tree, state, implementation));
 
     // Replace all uses of the identifier with a method reference.
-    Optional<SuggestedFix> methodReferenceReplacement =
-        replaceUsesWithMethodReference(newName, varSym, implementation, state);
-    if (!methodReferenceReplacement.isPresent()) {
-      return NO_MATCH;
-    }
-    fixBuilder.merge(methodReferenceReplacement.get());
-
-    return describeMatch(tree, fixBuilder.build());
+    return replaceUsesWithMethodReference(newName, varSym, implementation, state)
+        .map(mrr -> describeMatch(tree, fixBuilder.merge(mrr).build()))
+        .orElse(NO_MATCH);
   }
 
   /** Remove anonymous class definition beginning and end, leaving only the method definition. */
@@ -163,10 +159,10 @@ public class UnnecessaryAnonymousClass extends BugChecker implements VariableTre
   private static Optional<SuggestedFix> replaceUsesWithMethodReference(
       String newName, Symbol varSym, MethodTree implementation, VisitorState state) {
     // Extract method body.
-    JCTree methodBody = (JCTree) implementation.getBody();
+    BlockTree methodBody = implementation.getBody();
 
     // Scan entire compilation unit to replace all uses of the variable with method references.
-    JCCompilationUnit compilationUnit = (JCCompilationUnit) state.getPath().getCompilationUnit();
+    CompilationUnitTree compilationUnit = state.getPath().getCompilationUnit();
     ReplaceUsesScanner replaceUsesScanner = new ReplaceUsesScanner(varSym, newName, state);
     replaceUsesScanner.scan(compilationUnit, null);
 
@@ -176,14 +172,15 @@ public class UnnecessaryAnonymousClass extends BugChecker implements VariableTre
   }
 
   private static SuggestedFix ensureFixesDoNotOverlap(
-      JCTree methodBody, JCCompilationUnit compilationUnit, SuggestedFix fix, VisitorState state) {
+      Tree methodBody, CompilationUnitTree compilationUnit, SuggestedFix fix, VisitorState state) {
     StringBuilder methodBodySource =
         new StringBuilder(Objects.requireNonNull(state.getSourceForNode(methodBody)));
     Range<Integer> methodBodyPositionRange =
-        Range.closedOpen(methodBody.getStartPosition(), state.getEndPosition(methodBody));
+        Range.closedOpen(getStartPosition(methodBody), state.getEndPosition(methodBody));
     SuggestedFix.Builder fixBuilder = SuggestedFix.builder();
     // Apply each fix generated by ReplaceUsesScanner to fixBuilder.
-    for (Replacement replacement : fix.getReplacements(compilationUnit.endPositions)) {
+    for (Replacement replacement :
+        fix.getReplacements(((JCCompilationUnit) compilationUnit).endPositions)) {
       if (replacement.range().isConnected(methodBodyPositionRange)) {
         // If the usage replacement overlaps with the method body, apply it to the method body
         // source directly, to avoid fix collisions when we replace the whole thing.
@@ -260,7 +257,7 @@ public class UnnecessaryAnonymousClass extends BugChecker implements VariableTre
       }
     }
 
-    public Optional<SuggestedFix> getFixes() {
+    Optional<SuggestedFix> getFixes() {
       return failed ? Optional.empty() : Optional.of(fix.build());
     }
   }
