@@ -243,7 +243,8 @@ public class UnnecessaryDefaultInEnumSwitch extends BugChecker
     Description.Builder unrecognizedDescription =
         buildDescription(defaultCase).setMessage(DESCRIPTION_UNRECOGNIZED);
     if (defaultStatements == null) {
-      SuggestedFix fix = SuggestedFix.replace(defaultCase.getLabels().get(0), "case UNRECOGNIZED");
+      SuggestedFix fix =
+          SuggestedFix.replace(defaultCase.getLabels().getFirst(), "case UNRECOGNIZED");
       return compilesWithFix(fix, state) ? unrecognizedDescription.addFix(fix).build() : NO_MATCH;
     }
     if (trivialDefault(defaultStatements)) {
@@ -308,7 +309,7 @@ public class UnnecessaryDefaultInEnumSwitch extends BugChecker
     String defaultSource =
         sourceCode
             .subSequence(
-                getStartPosition(defaultStatements.get(0)),
+                getStartPosition(defaultStatements.getFirst()),
                 state.getEndPosition(getLast(defaultStatements)))
             .toString();
     String initialComments = comments(defaultCase, defaultStatements, sourceCode);
@@ -329,7 +330,7 @@ public class UnnecessaryDefaultInEnumSwitch extends BugChecker
     // "default:" to the first statement, and then strip off "default:", because
     // we have no way of identifying the end position of just the "default:" statement.
     int defaultStart = getStartPosition(defaultCase);
-    int statementStart = getStartPosition(defaultStatements.get(0));
+    int statementStart = getStartPosition(defaultStatements.getFirst());
     String defaultAndComments = sourceCode.subSequence(defaultStart, statementStart).toString();
     String comments =
         defaultAndComments
