@@ -93,7 +93,13 @@ public final class UnnecessaryQualifier extends BugChecker
     var symbol = getSymbol(tree);
     switch (symbol.getKind()) {
       case FIELD -> {
-        if (INJECTION_FIELDS.stream().anyMatch(ip -> hasAnnotation(tree, ip, state))) {
+        if (INJECTION_FIELDS.stream().anyMatch(ip -> hasAnnotation(tree, ip, state))
+            || tree.getModifiers().getAnnotations().stream()
+                .anyMatch(
+                    anno ->
+                        INJECTION_PREFIXES.stream()
+                            .anyMatch(
+                                p -> getSymbol(anno).getSimpleName().toString().startsWith(p)))) {
           return NO_MATCH;
         }
         if (isRecord(symbol)) {
@@ -160,7 +166,8 @@ public final class UnnecessaryQualifier extends BugChecker
 
   private Description deleteAnnotations(ImmutableList<AnnotationTree> annotations) {
     return describeMatch(
-        annotations.get(0), annotations.stream().map(SuggestedFix::delete).collect(mergeFixes()));
+        annotations.getFirst(),
+        annotations.stream().map(SuggestedFix::delete).collect(mergeFixes()));
   }
 
   private static ImmutableList<AnnotationTree> getQualifiers(
@@ -222,22 +229,14 @@ public final class UnnecessaryQualifier extends BugChecker
   private static final ImmutableSet<String> INJECTION_FIELDS =
       ImmutableSet.of(
           // keep-sorted start
-          "com.google.inject.Inject",
-          "dagger.Binds",
-          "dagger.BindsInstance",
-          "dagger.hilt.android.testing.BindElementsIntoSet",
-          "dagger.hilt.android.testing.BindValue",
-          "dagger.hilt.android.testing.BindValueIntoMap",
-          "dagger.hilt.android.testing.BindValueIntoSet",
-          "dagger.hilt.testing.BindElementsIntoSet",
-          "dagger.hilt.testing.BindValue",
-          "dagger.hilt.testing.BindValueIntoMap",
-          "dagger.hilt.testing.BindValueIntoSet",
-          "jakarta.inject.Inject",
-          "javax.inject.Inject"
+          // FlagSpec is obviously not an injecty annotation, but it's commonly used with
+          // FlagBinder, at which point qualifiers on the field are relevant.
           // keep-sorted end
           );
 
+  /** Prefixes for annotations on variables which can have qualifiers. */
+  private static final ImmutableSet<String> INJECTION_PREFIXES = ImmutableSet.of("Bind", "Inject");
+
   private static final ImmutableSet<String> CLASS_ANNOTATIONS_EXEMPTING_METHODS =
       ImmutableSet.of(
           // keep-sorted start
