@@ -18,7 +18,6 @@ package com.google.errorprone.bugpatterns.argumentselectiondefects;
 
 import static com.google.common.collect.ImmutableList.toImmutableList;
 
-import com.google.auto.value.AutoValue;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
@@ -29,6 +28,7 @@ import com.google.errorprone.names.NamingConventions;
 import com.google.errorprone.util.ASTHelpers;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
+import com.sun.source.tree.LiteralTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.NewClassTree;
@@ -51,9 +51,7 @@ import java.util.Optional;
  *
  * @author andrewrice@google.com (Andrew Rice)
  */
-@AutoValue
-abstract class Parameter {
-
+record Parameter(String name, Type type, int index, String text, Kind kind, boolean constant) {
   private static final ImmutableSet<String> METHODNAME_PREFIXES_TO_REMOVE =
       ImmutableSet.of("get", "set", "is");
 
@@ -63,23 +61,11 @@ abstract class Parameter {
   /** We use this placeholder to indicate a name which we couldn't get a canonical string for. */
   @VisibleForTesting static final String NAME_NOT_PRESENT = "*NOT_PRESENT*";
 
-  abstract String name();
-
-  abstract Type type();
-
-  abstract int index();
-
-  abstract String text();
-
-  abstract Kind kind();
-
-  abstract boolean constant();
-
   static ImmutableList<Parameter> createListFromVarSymbols(List<VarSymbol> varSymbols) {
     return Streams.mapWithIndex(
             varSymbols.stream(),
             (s, i) ->
-                new AutoValue_Parameter(
+                new Parameter(
                     s.getSimpleName().toString(),
                     s.asType(),
                     (int) i,
@@ -93,7 +79,7 @@ abstract class Parameter {
     return Streams.mapWithIndex(
             trees.stream(),
             (t, i) ->
-                new AutoValue_Parameter(
+                new Parameter(
                     getArgumentName(t),
                     Optional.ofNullable(
                             t instanceof ExpressionTree expressionTree
@@ -167,12 +153,12 @@ abstract class Parameter {
    */
   @VisibleForTesting
   static String getArgumentName(Tree tree) {
-    return switch (tree.getKind()) {
-      case VARIABLE -> ((VariableTree) tree).getName().toString();
-      case MEMBER_SELECT -> ((MemberSelectTree) tree).getIdentifier().toString();
+    return switch (tree) {
+      case VariableTree variableTree -> variableTree.getName().toString();
+      case MemberSelectTree memberSelectTree -> memberSelectTree.getIdentifier().toString();
       // null could match anything pretty well
-      case NULL_LITERAL -> NAME_NULL;
-      case IDENTIFIER -> {
+      case LiteralTree literalTree when tree.getKind().equals(Kind.NULL_LITERAL) -> NAME_NULL;
+      case IdentifierTree identifierTree -> {
         IdentifierTree idTree = (IdentifierTree) tree;
         if (idTree.getName().contentEquals("this")) {
           // for the 'this' keyword the argument name is the name of the object's class
@@ -183,8 +169,7 @@ abstract class Parameter {
           yield idTree.getName().toString();
         }
       }
-      case METHOD_INVOCATION -> {
-        MethodInvocationTree methodInvocationTree = (MethodInvocationTree) tree;
+      case MethodInvocationTree methodInvocationTree -> {
         MethodSymbol methodSym = ASTHelpers.getSymbol(methodInvocationTree);
         String name = methodSym.getSimpleName().toString();
         ImmutableList<String> terms = NamingConventions.splitToLowercaseTerms(name);
@@ -204,8 +189,8 @@ abstract class Parameter {
           yield name;
         }
       }
-      case NEW_CLASS -> {
-        MethodSymbol constructorSym = ASTHelpers.getSymbol((NewClassTree) tree);
+      case NewClassTree newClassTree -> {
+        MethodSymbol constructorSym = ASTHelpers.getSymbol(newClassTree);
         yield constructorSym.owner != null
             ? getClassName((ClassSymbol) constructorSym.owner)
             : NAME_NOT_PRESENT;
