@@ -20,7 +20,6 @@ import static com.google.common.collect.ImmutableSet.toImmutableSet;
 import static com.google.errorprone.util.ASTHelpers.getSymbol;
 import static com.google.errorprone.util.ASTHelpers.isStatic;
 
-import com.google.auto.value.AutoValue;
 import com.google.common.collect.ImmutableSet;
 import com.google.errorprone.VisitorState;
 import com.google.errorprone.bugpatterns.threadsafety.GuardedByExpression.Select;
@@ -43,7 +42,7 @@ import org.jspecify.annotations.Nullable;
  * @author cushon@google.com (Liam Miller-Cushon)
  */
 public final class GuardedByUtils {
-  public static ImmutableSet<String> getGuardValues(Symbol sym, GuardedByFlags flags) {
+  public static ImmutableSet<String> getGuardValues(Symbol sym) {
     List<Attribute.Compound> rawAttributes = sym.getRawAttributes();
     if (rawAttributes.isEmpty()) {
       return ImmutableSet.of();
@@ -51,10 +50,8 @@ public final class GuardedByUtils {
     return rawAttributes.stream()
         .filter(
             a ->
-                flags.includeSelectedGuardedBy()
-                    ? ACCEPTED_GUARDED_BY_ANNOTATIONS.contains(
-                        a.getAnnotationType().asElement().toString())
-                    : a.type.tsym.flatName().contentEquals(GUARDED_BY))
+                ACCEPTED_GUARDED_BY_ANNOTATIONS.contains(
+                    a.getAnnotationType().asElement().toString()))
         .flatMap(
             a ->
                 MoreAnnotations.getValue(a, "value")
@@ -63,13 +60,11 @@ public final class GuardedByUtils {
         .collect(toImmutableSet());
   }
 
-  static ImmutableSet<String> getGuardValues(Tree tree, GuardedByFlags flags) {
+  static ImmutableSet<String> getGuardValues(Tree tree) {
     Symbol sym = getSymbol(tree);
-    return sym == null ? ImmutableSet.of() : getGuardValues(sym, flags);
+    return sym == null ? ImmutableSet.of() : getGuardValues(sym);
   }
 
-  private static final String GUARDED_BY = "com.google.errorprone.annotations.concurrent.GuardedBy";
-
   private static final ImmutableSet<String> ACCEPTED_GUARDED_BY_ANNOTATIONS =
       ImmutableSet.of(
           "android.support.annotation.GuardedBy",
@@ -98,24 +93,18 @@ public final class GuardedByUtils {
     return exp;
   }
 
-  @AutoValue
-  abstract static class GuardedByValidationResult {
-    abstract String message();
-
-    abstract boolean isValid();
-
+  record GuardedByValidationResult(String message, boolean isValid) {
     static GuardedByValidationResult invalid(String message) {
-      return new AutoValue_GuardedByUtils_GuardedByValidationResult(message, false);
+      return new GuardedByValidationResult(message, false);
     }
 
     static GuardedByValidationResult ok() {
-      return new AutoValue_GuardedByUtils_GuardedByValidationResult("", true);
+      return new GuardedByValidationResult("", true);
     }
   }
 
-  public static GuardedByValidationResult isGuardedByValid(
-      Tree tree, VisitorState state, GuardedByFlags flags) {
-    ImmutableSet<String> guards = GuardedByUtils.getGuardValues(tree, flags);
+  public static GuardedByValidationResult isGuardedByValid(Tree tree, VisitorState state) {
+    ImmutableSet<String> guards = GuardedByUtils.getGuardValues(tree);
     if (guards.isEmpty()) {
       return GuardedByValidationResult.ok();
     }
@@ -123,8 +112,8 @@ public final class GuardedByUtils {
     List<GuardedByExpression> boundGuards = new ArrayList<>();
     for (String guard : guards) {
       Optional<GuardedByExpression> boundGuard =
-          GuardedByBinder.bindString(guard, GuardedBySymbolResolver.from(tree, state), flags);
-      if (!boundGuard.isPresent()) {
+          GuardedByBinder.bindString(guard, GuardedBySymbolResolver.from(tree, state));
+      if (boundGuard.isEmpty()) {
         return GuardedByValidationResult.invalid("could not resolve guard");
       }
       boundGuards.add(boundGuard.get());
@@ -155,13 +144,10 @@ public final class GuardedByUtils {
   }
 
   public static @Nullable Symbol bindGuardedByString(
-      Tree tree, String guard, VisitorState visitorState, GuardedByFlags flags) {
-    Optional<GuardedByExpression> bound =
-        GuardedByBinder.bindString(guard, GuardedBySymbolResolver.from(tree, visitorState), flags);
-    if (!bound.isPresent()) {
-      return null;
-    }
-    return bound.get().sym();
+      Tree tree, String guard, VisitorState visitorState) {
+    return GuardedByBinder.bindString(guard, GuardedBySymbolResolver.from(tree, visitorState))
+        .map(bound -> bound.sym())
+        .orElse(null);
   }
 
   private GuardedByUtils() {}
