@@ -91,7 +91,7 @@ final class PlaceholderVerificationVisitor extends TreeScanner<Boolean, Unifier>
   public Boolean visitIdentifier(IdentifierTree node, Unifier unifier) {
     for (LocalVarBinding localBinding :
         Iterables.filter(unifier.getBindings().values(), LocalVarBinding.class)) {
-      if (localBinding.getSymbol().equals(ASTHelpers.getSymbol(node))) {
+      if (localBinding.symbol().equals(ASTHelpers.getSymbol(node))) {
         return false;
       }
     }
