@@ -292,6 +292,7 @@ import com.google.errorprone.bugpatterns.NonFinalCompileTimeConstant;
 import com.google.errorprone.bugpatterns.NonFinalStaticField;
 import com.google.errorprone.bugpatterns.NonOverridingEquals;
 import com.google.errorprone.bugpatterns.NonRuntimeAnnotation;
+import com.google.errorprone.bugpatterns.NullNeedsCastForVarargs;
 import com.google.errorprone.bugpatterns.NullOptional;
 import com.google.errorprone.bugpatterns.NullTernary;
 import com.google.errorprone.bugpatterns.NullableConstructor;
@@ -484,7 +485,6 @@ import com.google.errorprone.bugpatterns.android.ParcelableCreator;
 import com.google.errorprone.bugpatterns.android.RectIntersectReturnValueIgnored;
 import com.google.errorprone.bugpatterns.android.StaticOrDefaultInterfaceMethod;
 import com.google.errorprone.bugpatterns.android.WakelockReleasedDangerously;
-import com.google.errorprone.bugpatterns.apidiff.AndroidJdkLibsChecker;
 import com.google.errorprone.bugpatterns.apidiff.Java8ApiChecker;
 import com.google.errorprone.bugpatterns.argumentselectiondefects.ArgumentSelectionDefectChecker;
 import com.google.errorprone.bugpatterns.argumentselectiondefects.AssertEqualsArgumentOrderChecker;
@@ -494,6 +494,7 @@ import com.google.errorprone.bugpatterns.checkreturnvalue.CanIgnoreReturnValueSu
 import com.google.errorprone.bugpatterns.checkreturnvalue.NoCanIgnoreReturnValueOnClasses;
 import com.google.errorprone.bugpatterns.checkreturnvalue.UnnecessarilyUsedValue;
 import com.google.errorprone.bugpatterns.checkreturnvalue.UsingJsr305CheckReturnValue;
+import com.google.errorprone.bugpatterns.collectionincompatibletype.AssertSameIncompatible;
 import com.google.errorprone.bugpatterns.collectionincompatibletype.CollectionIncompatibleType;
 import com.google.errorprone.bugpatterns.collectionincompatibletype.CollectionUndefinedEquality;
 import com.google.errorprone.bugpatterns.collectionincompatibletype.CompatibleWithMisuse;
@@ -516,6 +517,7 @@ import com.google.errorprone.bugpatterns.flogger.FloggerWithoutCause;
 import com.google.errorprone.bugpatterns.formatstring.AnnotateFormatMethod;
 import com.google.errorprone.bugpatterns.formatstring.FormatString;
 import com.google.errorprone.bugpatterns.formatstring.FormatStringAnnotationChecker;
+import com.google.errorprone.bugpatterns.formatstring.FormatStringShouldUsePlaceholders;
 import com.google.errorprone.bugpatterns.formatstring.InlineFormatString;
 import com.google.errorprone.bugpatterns.formatstring.LenientFormatStringValidation;
 import com.google.errorprone.bugpatterns.inject.AssistedInjectAndInjectOnConstructors;
@@ -585,6 +587,7 @@ import com.google.errorprone.bugpatterns.nullness.NullablePrimitiveArray;
 import com.google.errorprone.bugpatterns.nullness.NullableTypeParameter;
 import com.google.errorprone.bugpatterns.nullness.NullableWildcard;
 import com.google.errorprone.bugpatterns.nullness.ParameterMissingNullable;
+import com.google.errorprone.bugpatterns.nullness.RedundantNullCheck;
 import com.google.errorprone.bugpatterns.nullness.ReturnMissingNullable;
 import com.google.errorprone.bugpatterns.nullness.UnnecessaryCheckNotNull;
 import com.google.errorprone.bugpatterns.nullness.UnsafeWildcard;
@@ -785,6 +788,7 @@ public class BuiltInCheckerSuppliers {
           JUnitParameterMethodNotFound.class,
           JavaxInjectOnAbstractMethod.class,
           JodaToSelf.class,
+          LabelledBreakTarget.class,
           LenientFormatStringValidation.class,
           LiteByteStringUtf8.class,
           LocalDateTemporalAmount.class,
@@ -812,6 +816,7 @@ public class BuiltInCheckerSuppliers {
           NonFinalCompileTimeConstant.class,
           NonRuntimeAnnotation.class,
           NullArgumentForNonNullParameter.class,
+          NullNeedsCastForVarargs.class,
           NullTernary.class,
           NullableOnContainingClass.class,
           OptionalEquality.class,
@@ -890,6 +895,7 @@ public class BuiltInCheckerSuppliers {
           ArrayAsKeyOfSetOrMap.class,
           ArrayRecordComponent.class,
           AssertEqualsArgumentOrderChecker.class,
+          AssertSameIncompatible.class,
           AssertThrowsMultipleStatements.class,
           AssertionFailureIgnored.class,
           AssignmentExpression.class,
@@ -964,6 +970,7 @@ public class BuiltInCheckerSuppliers {
           FloggerArgumentToString.class,
           FloggerPerWithoutRateLimit.class,
           FloggerStringConcatenation.class,
+          FormatStringShouldUsePlaceholders.class,
           FragmentInjection.class,
           FragmentNotInstantiable.class,
           FutureReturnValueIgnored.class,
@@ -1027,7 +1034,6 @@ public class BuiltInCheckerSuppliers {
           JodaPlusMinusLong.class,
           JodaTimeConverterManager.class,
           JodaWithDurationAddedLong.class,
-          LabelledBreakTarget.class,
           LiteEnumValueOf.class,
           LiteProtoToString.class,
           LockNotBeforeTry.class,
@@ -1181,7 +1187,6 @@ public class BuiltInCheckerSuppliers {
       getSuppliers(
           // keep-sorted start
           AddNullMarkedToPackageInfo.class,
-          AndroidJdkLibsChecker.class,
           AnnotationMirrorToString.class,
           AnnotationPosition.class,
           AnnotationValueToString.class,
@@ -1267,6 +1272,7 @@ public class BuiltInCheckerSuppliers {
           PrivateConstructorForUtilityClass.class,
           PublicApiNamedStreamShouldReturnStream.class,
           QualifierWithTypeUse.class,
+          RedundantNullCheck.class,
           RedundantOverride.class,
           RedundantThrows.class,
           RefersToDaggerCodegen.class,
