@@ -16,8 +16,6 @@
 
 package com.google.errorprone.bugpatterns;
 
-import static com.google.common.truth.TruthJUnit.assume;
-
 import com.google.errorprone.BugCheckerRefactoringTestHelper;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -59,8 +57,6 @@ public class DeprecatedVariableTest {
 
   @Test
   public void refactorBindingVariables() {
-    assume().that(Runtime.version().feature()).isAtLeast(21);
-
     testHelper
         .addInputLines(
             "Test.java",
