@@ -71,6 +71,46 @@ public class UnsafeLocaleUsageTest {
         .doTest();
   }
 
+  @Test
+  public void unsafeLocaleUsageCheck_localeOfUsageWithOneParam_shouldRefactorNonLiteralParam() {
+    refactoringHelper
+        .addInputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              static class Inner {
+                private Locale locale;
+
+                Inner(String a) {
+                  locale = Locale.of(a);
+                }
+              }
+
+              private static final Test.Inner INNER_OBJ = new Inner("zh_hant_tw");
+            }
+            """)
+        .addOutputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              static class Inner {
+                private Locale locale;
+
+                Inner(String a) {
+                  locale = Locale.forLanguageTag(a.replace('_', '-'));
+                }
+              }
+
+              private static final Test.Inner INNER_OBJ = new Inner("zh_hant_tw");
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void unsafeLocaleUsageCheck_constructorUsageWithOneParam_shouldRefactorLiteralParam() {
     refactoringHelper
@@ -95,6 +135,30 @@ public class UnsafeLocaleUsageTest {
         .doTest();
   }
 
+  @Test
+  public void unsafeLocaleUsageCheck_localeOfUsageWithOneParam_shouldRefactorLiteralParam() {
+    refactoringHelper
+        .addInputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              private static final Locale LOCALE = Locale.of("zh_hant_tw");
+            }
+            """)
+        .addOutputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              private static final Locale LOCALE = Locale.forLanguageTag("zh-hant-tw");
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void unsafeLocaleUsageCheck_constructorUsageWithTwoParams_shouldRefactor() {
     refactoringHelper
@@ -125,7 +189,49 @@ public class UnsafeLocaleUsageTest {
                 private Locale locale;
 
                 Inner(String a, String b) {
-                  locale = new Locale.Builder().setLanguage(a).setRegion(b).build();
+                  // BUG: Diagnostic contains: forLanguageTag(String)
+                  locale = new Locale(a, b);
+                }
+              }
+
+              private static final Test.Inner INNER_OBJ = new Inner("zh", "tw");
+            }
+            """)
+        .doTest();
+  }
+
+  @Test
+  public void unsafeLocaleUsageCheck_localeOfUsageWithTwoParams_shouldRefactor() {
+    refactoringHelper
+        .addInputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              static class Inner {
+                private Locale locale;
+
+                Inner(String a, String b) {
+                  locale = Locale.of(a, b);
+                }
+              }
+
+              private static final Test.Inner INNER_OBJ = new Inner("zh", "tw");
+            }
+            """)
+        .addOutputLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              static class Inner {
+                private Locale locale;
+
+                Inner(String a, String b) {
+                  // BUG: Diagnostic contains: forLanguageTag(String)
+                  locale = Locale.of(a, b);
                 }
               }
 
@@ -159,6 +265,30 @@ public class UnsafeLocaleUsageTest {
         .doTest();
   }
 
+  @Test
+  public void unsafeLocaleUsageCheck_localeOfUsageWithThreeParams_shouldFlag() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              static class Inner {
+                private Locale locale;
+
+                Inner(String a, String b, String c) {
+                  // BUG: Diagnostic contains: forLanguageTag(String)
+                  locale = Locale.of(a, b, c);
+                }
+              }
+
+              private static final Test.Inner INNER_OBJ = new Inner("zh", "tw", "hant");
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void unsafeLocaleUsageCheck_toStringUsage_shouldRefactor() {
     refactoringHelper
@@ -208,7 +338,7 @@ public class UnsafeLocaleUsageTest {
   }
 
   @Test
-  public void unsafeLocaleUsageCheck_multipleErrors_shouldFlag() {
+  public void unsafeLocaleUsageCheck_multipleErrorsWithNew_shouldFlag() {
     compilationHelper
         .addSourceLines(
             "Test.java",
@@ -226,6 +356,25 @@ public class UnsafeLocaleUsageTest {
         .doTest();
   }
 
+  @Test
+  public void unsafeLocaleUsageCheck_multipleErrorsWithLocaleOf_shouldFlag() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import java.util.Locale;
+
+            class Test {
+              private static final Locale LOCALE =
+                  // BUG: Diagnostic contains: forLanguageTag(String)
+                  Locale.of(
+                      // BUG: Diagnostic contains: toLanguageTag()
+                      Locale.TAIWAN.toString());
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void unsafeLocaleUsageCheck_instanceMethodUsage_shouldNotFlag() {
     compilationHelper
