@@ -15,8 +15,6 @@
  */
 package com.google.errorprone.bugpatterns.argumentselectiondefects;
 
-import static com.google.common.truth.TruthJUnit.assume;
-
 import com.google.common.collect.ImmutableSet;
 import com.google.errorprone.BugPattern;
 import com.google.errorprone.BugPattern.SeverityLevel;
@@ -402,11 +400,40 @@ record Foo(String first, String second) {}
         .doTest();
   }
 
+  @Test
+  public void recordDeconstruction() {
+    testHelper
+        .addSourceLines(
+            "Test.java",
+"""
+class Test {
+  void test(Foo foo) {
+    switch (foo) {
+      // BUG: Diagnostic contains: may have been swapped
+      case Foo(String second, String first, _) -> {}
+      default -> {}
+    }
+  }
+
+  void test2(Foo foo) {
+    switch (foo) {
+      // BUG: Diagnostic contains: may have been swapped
+      case Foo(_, _, Foo(String second, String first, _)) -> {}
+      default -> {}
+    }
+  }
+}
+
+record Foo(String first, String second, Foo foo) {}
+""")
+        .setArgs("--enable-preview", "--release", Integer.toString(Runtime.version().feature()))
+        .doTest();
+  }
+
   public record Foo(String first, String second) {}
 
   @Test
   public void recordPattern() {
-    assume().that(Runtime.version().feature()).isAtLeast(21);
     testHelper
         .addSourceLines(
             "Test.java",
