@@ -1293,53 +1293,6 @@ public class Client {
         .doTest();
   }
 
-  @Test
-  public void importStatic_getsIncorrectlySuggestedAsImportsInsteadOfStaticImports() {
-    refactoringTestHelper
-        .addInputLines(
-            "KeymasterCrypter.java",
-            """
-            package com.google.security.keymaster;
-
-            import static java.nio.charset.StandardCharsets.US_ASCII;
-            import com.google.errorprone.annotations.InlineMe;
-
-            public final class KeymasterCrypter {
-              @Deprecated
-              public final String decryptASCII(byte[] ciphertext) {
-                return new String(decrypt(ciphertext), US_ASCII);
-              }
-
-              public byte[] decrypt(byte[] ciphertext) {
-                return ciphertext;
-              }
-            }
-
-            """)
-        .addOutputLines(
-            "KeymasterCrypter.java",
-            "package com.google.security.keymaster;",
-            "import static java.nio.charset.StandardCharsets.US_ASCII;",
-            "import com.google.errorprone.annotations.InlineMe;",
-            "public final class KeymasterCrypter {",
-            // TODO(b/242890437): This line is wrong:
-            "  @InlineMe(replacement = \"new String(this.decrypt(ciphertext), US_ASCII)\", imports"
-                + " = \"US_ASCII\")",
-            // It should be this instead:
-            // "  @InlineMe(",
-            // "      replacement = \"new String(this.decrypt(ciphertext), US_ASCII)\",",
-            // "      staticImports =\"java.nio.charset.StandardCharsets.US_ASCII\")",
-            "  @Deprecated",
-            "  public final String decryptASCII(byte[] ciphertext) {",
-            "    return new String(decrypt(ciphertext), US_ASCII);",
-            "  }",
-            "  public byte[] decrypt(byte[] ciphertext) {",
-            "    return ciphertext;",
-            "  }",
-            "}")
-        .doTest();
-  }
-
   @Test
   public void noInlineMeSuggestionWhenParameterNamesAreArgN() {
     refactoringTestHelper
@@ -1408,4 +1361,39 @@ public class Client {
         .expectUnchanged()
         .doTest();
   }
+
+  @Test
+  public void inlineMeSuggestionStaticImportInConstructor() {
+    refactoringTestHelper
+        .addInputLines(
+            "Client.java",
+            """
+            import static java.nio.charset.StandardCharsets.UTF_8;
+
+            public final class Client {
+              @Deprecated
+              public static String getString(byte[] bytes, int offset, int length) {
+                return new String(bytes, offset, length, UTF_8);
+              }
+            }
+            """)
+        .addOutputLines(
+            "Client.java",
+            """
+            import static java.nio.charset.StandardCharsets.UTF_8;
+
+            import com.google.errorprone.annotations.InlineMe;
+
+            public final class Client {
+              @InlineMe(
+                  replacement = "new String(bytes, offset, length, UTF_8)",
+                  staticImports = "java.nio.charset.StandardCharsets.UTF_8")
+              @Deprecated
+              public static String getString(byte[] bytes, int offset, int length) {
+                return new String(bytes, offset, length, UTF_8);
+              }
+            }
+            """)
+        .doTest();
+  }
 }
