@@ -1353,6 +1353,38 @@ class Test {
         .doTest();
   }
 
+  @Test
+  public void immutableTypeParam_alsoThreadSafe() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import com.google.errorprone.annotations.ThreadSafe;
+            import com.google.errorprone.annotations.ImmutableTypeParameter;
+
+            @ThreadSafe
+            class Test<@ImmutableTypeParameter T> {
+              final T t = null;
+            }
+            """)
+        .doTest();
+  }
+
+  @Test
+  public void immutableTypeParam_notInThreadSafeClass_ok() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import com.google.errorprone.annotations.ImmutableTypeParameter;
+
+            class Test<@ImmutableTypeParameter T> {
+              final T t = null;
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void threadSafeTypeParameterInstantiation() {
     compilationHelper
@@ -1602,4 +1634,38 @@ abstract class Recursive<T extends Recursive<T>> {
             """)
         .doTest();
   }
+
+  @Test
+  public void subtyping() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            package a;
+
+            import com.google.errorprone.annotations.ThreadSafe;
+
+            @ThreadSafe
+            interface ThreadSafeInterface {}
+
+            @ThreadSafe
+            abstract class ThreadSafeAbstractClass {}
+
+            // BUG: Diagnostic contains: is not annotated
+            class A implements ThreadSafeInterface {}
+
+            class C extends ThreadSafeAbstractClass {}
+
+            // BUG: Diagnostic contains: is not annotated
+            class E implements ThreadSafeInterface {
+              Object unsafe;
+            }
+
+            class G extends ThreadSafeAbstractClass {
+              // BUG: Diagnostic contains: fields should be final or annotated with @GuardedBy
+              Object unsafe;
+            }
+            """)
+        .doTest();
+  }
 }
