@@ -1179,7 +1179,7 @@ public class SuggestedFixesTest {
             """)
         .addOutputLines(
             "out/Test.java",
-            """
+"""
 import java.util.List;
 import java.util.Map;
 
@@ -1393,7 +1393,7 @@ class Test {
             """)
         .addOutputLines(
             "out/Test.java",
-            """
+"""
 public class Test {
   // Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut
   // labore et dolore magna aliqua.
@@ -2098,6 +2098,55 @@ public class Test {
         .doTest(TEXT_MATCH);
   }
 
+  /** A {@link BugChecker} for testing. */
+  @BugPattern(summary = "RenameClassChecker", severity = ERROR)
+  public static class RenameClassChecker extends BugChecker implements ClassTreeMatcher {
+    @Override
+    public Description matchClass(ClassTree tree, VisitorState state) {
+      return describeMatch(tree, SuggestedFixes.renameClassWithUses(tree, "Foo", state));
+    }
+  }
+
+  @Test
+  public void renameClass() {
+    BugCheckerRefactoringTestHelper.newInstance(RenameClassChecker.class, getClass())
+        .addInputLines(
+            "Test.java",
+            """
+            class Test {
+              Test get() {
+                return null;
+              }
+            }
+            """)
+        .addOutputLines(
+            "Test.java",
+            """
+            class Foo {
+              Foo get() {
+                return null;
+              }
+            }
+            """)
+        .doTest();
+  }
+
+  @Test
+  public void renameClass_selfReferential() {
+    BugCheckerRefactoringTestHelper.newInstance(RenameClassChecker.class, getClass())
+        .addInputLines(
+            "Test.java",
+            """
+            class Test<T extends Test<T>> {}
+            """)
+        .addOutputLines(
+            "Test.java",
+            """
+            class Foo<T extends Foo<T>> {}
+            """)
+        .doTest();
+  }
+
   /**
    * Test checker that raises a diagnostic with the result of {@link SuggestedFixes#qualifyType} on
    * new instances.
